==> cutetube_1.7.0.tar.gz: cutetube-1.7.0/cutetubeapp/src/base/transferlistmodel.h <==
#ifndef TransferListModel_H
#define TransferListModel_H

#include "transferitem.h"
#include <QAbstractListModel>
#include <QSharedPointer>

class TransferListModel : public QAbstractListModel
{
    Q_OBJECT

    Q_ENUMS(TransferListModel::Roles)

    Q_PROPERTY(Session* session
               READ session
               WRITE setSession)
    Q_PROPERTY(int count
               READ rowCount
               NOTIFY countChanged)
    Q_PROPERTY(bool itemsSelected
               READ itemsSelected
               NOTIFY itemsSelectedChanged)

public:
    enum Roles {
        FileNameRole = Qt::UserRole + 1,
        TitleRole,
        DownloadPathRole,
        StatusRole,
        StatusTextRole,
        StatusInfoRole,
        ProgressRole,
        SizeRole,
        PriorityRole,
        PriorityTextRole,
        ConvertibleToAudioRole,
        SaveAsAudioRole,
        ServiceRole,
        TransferTypeRole,
        SelectedRole
    };

public:
    explicit TransferListModel(Session *session = 0, QObject *parent = 0);
    ~TransferListModel();
    Session* session() const { return m_session; }
    void setSession(Session *session);
    int rowCount(const QModelIndex &parent = QModelIndex()) const;
    QVariant data(const QModelIndex &index, int role) const;
    Q_INVOKABLE QVariant data(int row, const QByteArray &role) const;
    bool setData(const QModelIndex &index, const QVariant &value, int role);
    Q_INVOKABLE bool setData(int row, const QVariant &value, const QByteArray &role);
    QSharedPointer<TransferItem> get(int row) const;
    Q_INVOKABLE TransferItem* getFromQML(int row) const;
    inline bool itemsSelected() const { return !m_selectedRows.isEmpty(); }

public slots:
    void moveTransfer(int sourceRow, int destinationRow);
    void toggleSelected(int row);
    void selectAll();
    void selectNone();
    void pauseSelectedTransfers();
    void resumeSelectedTransfers();
    void cancelSelectedTransfers();
    void moveSelectedTransfers(int destinationRow);

private:
    void clearTransfers();
    void selectRow(int row);
    void unselectRow(int row);
    int indexOf(TransferItem *transfer) const;

private slots:
    void onTransferStatusChanged();
    void onTransferProgressChanged();
    void onTransferSizeChanged();
    void onTransferFileNameChanged();
    void onTransferPriorityChanged();
    void onTransferRemoved(int row);

signals:
    void countChanged(int count);
    void itemsSelectedChanged(bool selected);

private:
    Session *m_session;
    QList<int> m_selectedRows;
};

#endif // TransferListModel_H

==> cutetube_1.7.3.tar.gz: cutetube-1.7.3/cutetubeapp/src/base/transferlistmodel.h <==
#ifndef TransferListModel_H
#define TransferListModel_H

#include "transferitem.h"
#include <QAbstractListModel>
#include <QSharedPointer>

class TransferListModel : public QAbstractListModel
{
    Q_OBJECT

    Q_ENUMS(TransferListModel::Roles)

    Q_PROPERTY(int count
               READ rowCount
               NOTIFY countChanged)
    Q_PROPERTY(bool itemsSelected
               READ itemsSelected
               NOTIFY itemsSelectedChanged)

public:
    enum Roles {
        FileNameRole = Qt::UserRole + 1,
        TitleRole,
        DownloadPathRole,
        StatusRole,
        StatusTextRole,
        StatusInfoRole,
        ProgressRole,
        SizeRole,
        PriorityRole,
        PriorityTextRole,
        ConvertibleToAudioRole,
        SaveAsAudioRole,
        ServiceRole,
        TransferTypeRole,
        SelectedRole
    };

public:
    explicit TransferListModel(QObject *parent = 0);
    ~TransferListModel();
    int rowCount(const QModelIndex &parent = QModelIndex()) const;
    QVariant data(const QModelIndex &index, int role) const;
    Q_INVOKABLE QVariant data(int row, const QByteArray &role) const;
    bool setData(const QModelIndex &index, const QVariant &value, int role);
    Q_INVOKABLE bool setData(int row, const QVariant &value, const QByteArray &role);
    QSharedPointer<TransferItem> get(int row) const;
#ifdef QML_USER_INTERFACE
    Q_INVOKABLE TransferItem* getFromQML(int row) const;
#endif
    inline bool itemsSelected() const { return !m_selectedRows.isEmpty(); }

public slots:
    void toggleSelected(int row);
    void selectAll();
    void selectNone();
    void pauseSelectedTransfers();
    void resumeSelectedTransfers();
    void cancelSelectedTransfers();

private:
    void clearTransfers();
    void selectRow(int row);
    void unselectRow(int row);
    int indexOf(TransferItem *transfer) const;

private slots:
    void onTransferStatusChanged();
    void onTransferProgressChanged();
    void onTransferSizeChanged();
    void onTransferFileNameChanged();
    void onTransferPriorityChanged();
    void onTransferRemoved(int row);

signals:
    void countChanged(int count);
    void itemsSelectedChanged(bool selected);

private:
    QList<int> m_selectedRows;
};

#endif // TransferListModel_H
